@@ -583,7 +583,7 @@ class CameraConfig(BaseCameraConfig):
 
 
 class CameraDelegate(Protocol):
-    async def snapshot(self) -> Optional[bytes]: ...
+    async def snapshot(self, source_id: str, force_new: Optional[bool] = None) -> Optional[bytes]: ...
 
 
 class CameraPTZDelegate(Protocol):
@@ -607,6 +607,8 @@ class CameraBaseSource(Protocol):
     internal: bool
     # end CameraInput
 
+    async def snapshot(self, force_new: Optional[bool] = None) -> Optional[bytes]: ...
+
     async def probe_stream(
         self, probe_config: Optional[ProbeConfig] = None, refresh: Optional[bool] = None
     ) -> Optional[ProbeStream]: ...
@@ -795,8 +797,6 @@ class CameraDevice(Protocol):
 
     logger: "LoggerService"
 
-    async def snapshot(self, force_new: Optional[bool] = None) -> Optional[bytes]: ...
-
     @overload
     def on_state_change(
         self, state_name: Literal["light"]
@@ -963,6 +963,7 @@ class DeviceManager(Protocol):
 
 @runtime_checkable
 class CoreManager(Protocol):
+    async def connect_to_plugin(self, plugin_name: str) -> "Optional[PluginInterface]": ...
     async def get_ffmpeg_path(self) -> str: ...
     async def get_hwaccel_info(
         self, target_codec: Union[Literal["h264"], Literal["h265"]]
@@ -1112,7 +1113,7 @@ class AudioMetadata(TypedDict):
 
 
 class MotionDetectionPluginResponse(TypedDict):
-    filePath: str
+    videoData: bytes
 
 
 class ObjectDetectionPluginResponse(TypedDict):
@@ -1129,33 +1130,49 @@ class BasePlugin(metaclass=ABCMeta):
     @abstractmethod
     async def onFormSubmit(self, action_id: str, payload: Any) -> Union[FormSubmitResponse, None]: ...
     @abstractmethod
-    def configureCameras(self, cameras: list[CameraDevice]) -> None: ...
+    async def configureCameras(self, cameras: list[CameraDevice]) -> None: ...
 
 
 class MotionDetectionPlugin(BasePlugin):
     @abstractmethod
-    def interfaceSchema(self) -> Optional[RootSchema]: ...
+    async def interfaceSchema(self) -> Optional[RootSchema]: ...
     @abstractmethod
     async def detectMotion(
-        self, video_path: str, config: dict[str, Any]
+        self, video_data: bytes, config: dict[str, Any]
     ) -> MotionDetectionPluginResponse: ...
 
 
 class ObjectDetectionPlugin(BasePlugin):
     @abstractmethod
-    def interfaceSchema(self) -> Optional[RootSchema]: ...
+    async def interfaceSchema(self) -> Optional[RootSchema]: ...
     @abstractmethod
     async def detectObjects(
-        self, image_path: str, metadata: ImageMetadata, config: dict[str, Any]
+        self, image_data: bytes, metadata: ImageMetadata, config: dict[str, Any]
     ) -> ObjectDetectionPluginResponse: ...
 
 
 class AudioDetectionPlugin(BasePlugin):
     @abstractmethod
-    def interfaceSchema(self) -> Optional[RootSchema]: ...
+    async def interfaceSchema(self) -> Optional[RootSchema]: ...
     @abstractmethod
     async def detectAudio(
-        self, audio_path: str, metadata: AudioMetadata, config: dict[str, Any]
+        self, audio_data: bytes, metadata: AudioMetadata, config: dict[str, Any]
+    ) -> AudioDetectionPluginResponse: ...
+
+
+@runtime_checkable
+class PluginInterface(Protocol):
+    async def onFormSubmit(self, action_id: str, payload: Any) -> Union[FormSubmitResponse, None]: ...
+    async def configureCameras(self, camera_devices: list[CameraDevice]) -> None: ...
+    async def interfaceSchema(self) -> Optional[RootSchema]: ...
+    async def detectMotion(
+        self, video_data: bytes, config: dict[str, Any]
+    ) -> MotionDetectionPluginResponse: ...
+    async def detectObjects(
+        self, image_data: bytes, metadata: ImageMetadata, config: dict[str, Any]
+    ) -> ObjectDetectionPluginResponse: ...
+    async def detectAudio(
+        self, audio_data: bytes, metadata: AudioMetadata, config: dict[str, Any]
     ) -> AudioDetectionPluginResponse: ...
 
 
